@@ -1,6 +1,3 @@
-require 'rubygems'
-require 'spec'
-
 $: << File.expand_path(File.join(File.dirname(__FILE__),"..","lib"))
 #require 'amalgalite/requires'
 
