@@ -1,7 +1,4 @@
-require 'rubygems'
-require 'spec'
-
-$: << File.expand_path(File.join(File.dirname(__FILE__),"..","lib"))
+require File.expand_path( File.join( File.dirname( __FILE__ ), "spec_helper.rb" ) )
 require 'amalgalite/type_maps/text_map'
 
 describe Amalgalite::TypeMaps::TextMap do
